\name{EMBO03}

\alias{EMBO03}

\title{EMBO 2003: Bioconductor Short Course}

\description{This package provides lecture notes and computer labs for
the short course "The Bioconductor Project: Open-source Statistical
Software for the Analysis of Microarray Data" given at EMBO, March 18,
2003. 

There are four labs: 
\item
"Lab1: R and Bioconductor Basics"  (lab1Basics.Rnw)
\item
"Lab2: Introduction to Bioconductor Annotation Packages"  (lab2Annot.Rnw)
\item
"Lab3: Introduction to Bioconductor \code{marray} Packages" (lab3Marray.Rnw)
\item
"Lab4: Introduction to Bioconductor \code{affy} Package" (lab4Affy.Rnw).

You can use the \code{\link{vExplorer}} function to interactively step
through the labs.
}

\author{Sandrine Dudoit, Robert Gentleman, and Rafael Irizarry.}

\references{\url{http://www.bioconductor.org}}

\examples{
#library(tkWidgets)
#vExplorer()
}

\keyword{shortcourse}
\name{getSYMBOL}
\alias{getSYMBOL}
\alias{getGO}
\alias{getGOdesc}
\alias{getPMID}
\alias{getLL}
\title{Functions to deal with Data Packages}
\description{
  The functions documented here are intended to make it easier to map
  from a set of manufacturers identifiers (such as you will get from the
  chips etc) to other identifiers.
}
\usage{
getSYMBOL(x, data = "hgu95a")
getLL(x, data = "hgu95a")
getGO(x, data = "hgu95a")
getPMID(x, data = "hgu95a")
getGOdesc(x, which=c("MF","BP","CC") )
}
\arguments{
  \item{x}{The identifiers to be mapped (usually manufacturer)}
  \item{data}{A character string identifying the data source }
  \item{which}{For \code{getGOdesc} indicates which GO hierarchy to use.}
}
\details{
  Appropriate translations are done. In some cases such as \code{getLL}
  and \code{getSYMBOL} there will only be one match and a vector is
  returned. In other cases such as \code{getPMID} and \code{getGO} there
  may be multiple matches and a list is returned.
  For \code{getGOdesc} the input vector is GO identifiers (not
  manufacturer identifiers) and in the output any identifier that does
  not have a description in the selected GO hierarchy (MF, BP or CC) is
  dropped. 
}
\value{
  Either a vector or a list depending on whether multiple values per
  input are possible.
}
\author{R. Gentleman}
\seealso{\code{\link{multiget}}}
\examples{
  data(eset)
  gN <- geneNames(eset)[100:105]
  getSYMBOL(gN)
  gg<- getGO(gN)
  getGOdesc(gg[[2]], "MF")
  getLL(gN)
  getPMID(gN)
}
\keyword{manip}
\name{hu6800ChrClass}
\alias{hu6800ChrClass}
\non_function{}
\title{An object of class chromLocation for the HU6800 chip}
\usage{data(hu6800ChrClass)}
\description{
  The Bioconductor plotting functions in \code{geneplotter} rely on objects of class 
 \code{chromLocation}. This dataset contains an object of class chromLocation for the HU6800 chip.}
}
\format{
 \code{hu6800ChrClass} is an object of class \code{\link{chromLocation}}.
}
\source{
 The   \code{hu6800ChrClass} object was constructed using the byChroms vignette in the \code{geneplotter} package. 
}

\examples{
data(hu6800ChrClass)
cPlot(hu6800ChrClass)
}
\keyword{datasets}
